==> kdeutils-4.4.3-x86_64-1.txz: install/doinst.sh <==

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
fi

( cd usr/share/doc/HTML/en/okteta ; rm -rf common )
( cd usr/share/doc/HTML/en/okteta ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcmlirc ; rm -rf common )
( cd usr/share/doc/HTML/en/kcmlirc ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/printer-applet ; rm -rf common )
( cd usr/share/doc/HTML/en/printer-applet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfloppy ; rm -rf common )
( cd usr/share/doc/HTML/en/kfloppy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcharselect ; rm -rf common )
( cd usr/share/doc/HTML/en/kcharselect ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcalc ; rm -rf common )
( cd usr/share/doc/HTML/en/kcalc ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktimer ; rm -rf common )
( cd usr/share/doc/HTML/en/ktimer ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdf ; rm -rf common )
( cd usr/share/doc/HTML/en/kdf ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/superkaramba ; rm -rf common )
( cd usr/share/doc/HTML/en/superkaramba ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/en/kwallet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/irkick ; rm -rf common )
( cd usr/share/doc/HTML/en/irkick ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kgpg ; rm -rf common )
( cd usr/share/doc/HTML/en/kgpg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/blockdevices ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/blockdevices ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ark ; rm -rf common )
( cd usr/share/doc/HTML/en/ark ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/bin ; rm -rf printer-applet )
( cd usr/bin ; ln -sf /usr/share/apps/printer-applet/printer-applet.py printer-applet )
( cd usr/lib64 ; rm -rf libsuperkaramba.so.4 )
( cd usr/lib64 ; ln -sf libsuperkaramba.so.4.4.0 libsuperkaramba.so.4 )
( cd usr/lib64 ; rm -rf liboktetacore.so.4 )
( cd usr/lib64 ; ln -sf liboktetacore.so.4.4.0 liboktetacore.so.4 )
( cd usr/lib64 ; rm -rf liboktetagui.so )
( cd usr/lib64 ; ln -sf liboktetagui.so.4 liboktetagui.so )
( cd usr/lib64 ; rm -rf liboktetagui.so.4 )
( cd usr/lib64 ; ln -sf liboktetagui.so.4.4.0 liboktetagui.so.4 )
( cd usr/lib64 ; rm -rf liboktetakastencore.so.4 )
( cd usr/lib64 ; ln -sf liboktetakastencore.so.4.4.0 liboktetakastencore.so.4 )
( cd usr/lib64 ; rm -rf libkastengui.so )
( cd usr/lib64 ; ln -sf libkastengui.so.4 libkastengui.so )
( cd usr/lib64 ; rm -rf libkastencore.so.4 )
( cd usr/lib64 ; ln -sf libkastencore.so.4.4.0 libkastencore.so.4 )
( cd usr/lib64 ; rm -rf libkastencore.so )
( cd usr/lib64 ; ln -sf libkastencore.so.4 libkastencore.so )
( cd usr/lib64 ; rm -rf libkerfuffle.so.4 )
( cd usr/lib64 ; ln -sf libkerfuffle.so.4.4.0 libkerfuffle.so.4 )
( cd usr/lib64 ; rm -rf liboktetakastengui.so.4 )
( cd usr/lib64 ; ln -sf liboktetakastengui.so.4.4.0 liboktetakastengui.so.4 )
( cd usr/lib64 ; rm -rf liboktetakastengui.so )
( cd usr/lib64 ; ln -sf liboktetakastengui.so.4 liboktetakastengui.so )
( cd usr/lib64 ; rm -rf liboktetakastencore.so )
( cd usr/lib64 ; ln -sf liboktetakastencore.so.4 liboktetakastencore.so )
( cd usr/lib64 ; rm -rf liboktetakastencontrollers.so.4 )
( cd usr/lib64 ; ln -sf liboktetakastencontrollers.so.4.4.0 liboktetakastencontrollers.so.4 )
( cd usr/lib64 ; rm -rf libkerfuffle.so )
( cd usr/lib64 ; ln -sf libkerfuffle.so.4 libkerfuffle.so )
( cd usr/lib64 ; rm -rf libkastengui.so.4 )
( cd usr/lib64 ; ln -sf libkastengui.so.4.4.0 libkastengui.so.4 )
( cd usr/lib64 ; rm -rf libkdelirc_shared.so.1 )
( cd usr/lib64 ; ln -sf libkdelirc_shared.so.1.0.0 libkdelirc_shared.so.1 )
( cd usr/lib64 ; rm -rf liboktetacore.so )
( cd usr/lib64 ; ln -sf liboktetacore.so.4 liboktetacore.so )
( cd usr/lib64 ; rm -rf liboktetakastencontrollers.so )
( cd usr/lib64 ; ln -sf liboktetakastencontrollers.so.4 liboktetakastencontrollers.so )
( cd usr/lib64 ; rm -rf libsuperkaramba.so )
( cd usr/lib64 ; ln -sf libsuperkaramba.so.4 libsuperkaramba.so )
( cd usr/lib64 ; rm -rf libkastencontrollers.so )
( cd usr/lib64 ; ln -sf libkastencontrollers.so.4 libkastencontrollers.so )
( cd usr/lib64 ; rm -rf libkdelirc_shared.so )
( cd usr/lib64 ; ln -sf libkdelirc_shared.so.1 libkdelirc_shared.so )
( cd usr/lib64 ; rm -rf libkastencontrollers.so.4 )
( cd usr/lib64 ; ln -sf libkastencontrollers.so.4.4.0 libkastencontrollers.so.4 )

==> kdeutils-4.5.5-x86_64-1.txz: install/doinst.sh <==

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib64 ; rm -rf libsuperkaramba.so.4 )
( cd usr/lib64 ; ln -sf libsuperkaramba.so.4.5.0 libsuperkaramba.so.4 )
( cd usr/lib64 ; rm -rf libsuperkaramba.so )
( cd usr/lib64 ; ln -sf libsuperkaramba.so.4 libsuperkaramba.so )
( cd usr/lib64 ; rm -rf liboktetakastencore.so )
( cd usr/lib64 ; ln -sf liboktetakastencore.so.4 liboktetakastencore.so )
( cd usr/lib64 ; rm -rf libkastencore.so )
( cd usr/lib64 ; ln -sf libkastencore.so.4 libkastencore.so )
( cd usr/lib64 ; rm -rf liblibkremotecontrol.so )
( cd usr/lib64 ; ln -sf liblibkremotecontrol.so.1 liblibkremotecontrol.so )
( cd usr/lib64 ; rm -rf liboktetacore.so.4 )
( cd usr/lib64 ; ln -sf liboktetacore.so.4.5.0 liboktetacore.so.4 )
( cd usr/lib64 ; rm -rf libkastencontrollers.so.4 )
( cd usr/lib64 ; ln -sf libkastencontrollers.so.4.5.0 libkastencontrollers.so.4 )
( cd usr/lib64 ; rm -rf libkastengui.so.4 )
( cd usr/lib64 ; ln -sf libkastengui.so.4.5.0 libkastengui.so.4 )
( cd usr/lib64 ; rm -rf liboktetakastengui.so.4 )
( cd usr/lib64 ; ln -sf liboktetakastengui.so.4.5.0 liboktetakastengui.so.4 )
( cd usr/lib64 ; rm -rf liboktetakastengui.so )
( cd usr/lib64 ; ln -sf liboktetakastengui.so.4 liboktetakastengui.so )
( cd usr/lib64 ; rm -rf liboktetagui.so )
( cd usr/lib64 ; ln -sf liboktetagui.so.4 liboktetagui.so )
( cd usr/lib64 ; rm -rf liblibkremotecontrol.so.1 )
( cd usr/lib64 ; ln -sf liblibkremotecontrol.so.1.0.0 liblibkremotecontrol.so.1 )
( cd usr/lib64 ; rm -rf liboktetakastencontrollers.so )
( cd usr/lib64 ; ln -sf liboktetakastencontrollers.so.4 liboktetakastencontrollers.so )
( cd usr/lib64 ; rm -rf libkerfuffle.so.4 )
( cd usr/lib64 ; ln -sf libkerfuffle.so.4.5.0 libkerfuffle.so.4 )
( cd usr/lib64 ; rm -rf libkastencore.so.4 )
( cd usr/lib64 ; ln -sf libkastencore.so.4.5.0 libkastencore.so.4 )
( cd usr/lib64 ; rm -rf liboktetacore.so )
( cd usr/lib64 ; ln -sf liboktetacore.so.4 liboktetacore.so )
( cd usr/lib64 ; rm -rf liboktetakastencontrollers.so.4 )
( cd usr/lib64 ; ln -sf liboktetakastencontrollers.so.4.5.0 liboktetakastencontrollers.so.4 )
( cd usr/lib64 ; rm -rf libkerfuffle.so )
( cd usr/lib64 ; ln -sf libkerfuffle.so.4 libkerfuffle.so )
( cd usr/lib64 ; rm -rf libkastencontrollers.so )
( cd usr/lib64 ; ln -sf libkastencontrollers.so.4 libkastencontrollers.so )
( cd usr/lib64 ; rm -rf liboktetagui.so.4 )
( cd usr/lib64 ; ln -sf liboktetagui.so.4.5.0 liboktetagui.so.4 )
( cd usr/lib64 ; rm -rf liboktetakastencore.so.4 )
( cd usr/lib64 ; ln -sf liboktetakastencore.so.4.5.0 liboktetakastencore.so.4 )
( cd usr/lib64 ; rm -rf libkastengui.so )
( cd usr/lib64 ; ln -sf libkastengui.so.4 libkastengui.so )
( cd usr/bin ; rm -rf printer-applet )
( cd usr/bin ; ln -sf /usr/share/apps/printer-applet/printer-applet.py printer-applet )
( cd usr/share/doc/HTML/en/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/en/kwallet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ktimer ; rm -rf common )
( cd usr/share/doc/HTML/en/ktimer ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdf ; rm -rf common )
( cd usr/share/doc/HTML/en/kdf ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/sweeper ; rm -rf common )
( cd usr/share/doc/HTML/en/sweeper ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/okteta ; rm -rf common )
( cd usr/share/doc/HTML/en/okteta ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kremotecontrol ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kremotecontrol ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/blockdevices ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/blockdevices ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kgpg ; rm -rf common )
( cd usr/share/doc/HTML/en/kgpg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcharselect ; rm -rf common )
( cd usr/share/doc/HTML/en/kcharselect ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/printer-applet ; rm -rf common )
( cd usr/share/doc/HTML/en/printer-applet ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ark ; rm -rf common )
( cd usr/share/doc/HTML/en/ark ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcalc ; rm -rf common )
( cd usr/share/doc/HTML/en/kcalc ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfloppy ; rm -rf common )
( cd usr/share/doc/HTML/en/kfloppy ; ln -sf /usr/share/doc/HTML/en/common common )
